==> xlniuxdata-vipgame-1.0.25-20150908.083901-3-sources.jar: com/xunlei/niux/data/vipgame/vo/business/AgentMonthIncome.java <==
package com.xunlei.niux.data.vipgame.vo.business;


import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * @author lisu
 *  2015-01-08
 *   独运月结
 */
@Table(tableName = "agentmonthincome", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentMonthIncome {
      private Long seqId;
      private String platformNo;
      private String gameId;
      private String month;
      private String totalMoney;
      private String testMoney;
      private String realTotalMoney;
      private String xunleiMoney;
      private String parterMoney;
      private String developMoney;
      private String realMoney;
      
      
      @Column(columnName="month",isWhereColumn=true,operator= Operator.GE)
      private String fromMonth;

      @Column(columnName="month",isWhereColumn=true,operator=Operator.LT)
      private String toMonth;
        
      

		public String getMonth() {
			return month;
		}
		public void setMonth(String month) {
			this.month = month;
		}
		public String getFromMonth() {
			return fromMonth;
		}
		public void setFromMonth(String fromMonth) {
			this.fromMonth = fromMonth;
		}
		public String getToMonth() {
			return toMonth;
		}
		public void setToMonth(String toMonth) {
			this.toMonth = toMonth;
		}
		public Long getSeqId() {
			return seqId;
		}
		public void setSeqId(Long seqId) {
			this.seqId = seqId;
		}
		public String getPlatformNo() {
			return platformNo;
		}
		public void setPlatformNo(String platformNo) {
			this.platformNo = platformNo;
		}
		public String getGameId() {
			return gameId;
		}
		public void setGameId(String gameId) {
			this.gameId = gameId;
		}
		public String getTotalMoney() {
			return totalMoney;
		}
		public void setTotalMoney(String totalMoney) {
			this.totalMoney = totalMoney;
		}
		public String getTestMoney() {
			return testMoney;
		}
		public void setTestMoney(String testMoney) {
			this.testMoney = testMoney;
		}
		public String getRealTotalMoney() {
			return realTotalMoney;
		}
		public void setRealTotalMoney(String realTotalMoney) {
			this.realTotalMoney = realTotalMoney;
		}
		public String getXunleiMoney() {
			return xunleiMoney;
		}
		public void setXunleiMoney(String xunleiMoney) {
			this.xunleiMoney = xunleiMoney;
		}
		public String getParterMoney() {
			return parterMoney;
		}
		public void setParterMoney(String parterMoney) {
			this.parterMoney = parterMoney;
		}
		public String getDevelopMoney() {
			return developMoney;
		}
		public void setDevelopMoney(String developMoney) {
			this.developMoney = developMoney;
		}
		public String getRealMoney() {
			return realMoney;
		}
		public void setRealMoney(String realMoney) {
			this.realMoney = realMoney;
		}
		
      
}

==> xlniuxdata-vipgame-1.0.65-20181221.064246-123-sources.jar: com/xunlei/niux/data/vipgame/vo/business/AgentMonthIncome.java <==
package com.xunlei.niux.data.vipgame.vo.business;


import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;
import com.xunlei.common.util.Extendable;


/**
 * @author lisu
 *  2015-01-08
 *   独运月结
 */
@Table(tableName = "agentmonthincome", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentMonthIncome {
      private Long seqId;
      private String platformNo;
      private String gameId;
      private String month;
      private String totalMoney;
      private String testMoney;
      private String realTotalMoney;
      private String xunleiMoney;
      private String parterMoney;
      private String developMoney;
      private String realMoney;
      
      
      @Column(columnName="month",isWhereColumn=true,operator= Operator.GE)
      private String fromMonth;

      @Column(columnName="month",isWhereColumn=true,operator=Operator.LT)
      private String toMonth;
      @Exclude
      private Integer clientType; //客户端类型
        
      public Integer getClientType() {
			return clientType;
		}
		public void setClientType(Integer clientType) {
			this.clientType = clientType;
		}
		public String getMonth() {
			return month;
		}
		public void setMonth(String month) {
			this.month = month;
		}
		public String getFromMonth() {
			return fromMonth;
		}
		public void setFromMonth(String fromMonth) {
			this.fromMonth = fromMonth;
		}
		public String getToMonth() {
			return toMonth;
		}
		public void setToMonth(String toMonth) {
			this.toMonth = toMonth;
		}
		public Long getSeqId() {
			return seqId;
		}
		public void setSeqId(Long seqId) {
			this.seqId = seqId;
		}
		public String getPlatformNo() {
			return platformNo;
		}
		public void setPlatformNo(String platformNo) {
			this.platformNo = platformNo;
		}
		public String getGameId() {
			return gameId;
		}
		public void setGameId(String gameId) {
			this.gameId = gameId;
		}
		public String getTotalMoney() {
			return totalMoney;
		}
		public void setTotalMoney(String totalMoney) {
			this.totalMoney = totalMoney;
		}
		public String getTestMoney() {
			return testMoney;
		}
		public void setTestMoney(String testMoney) {
			this.testMoney = testMoney;
		}
		public String getRealTotalMoney() {
			return realTotalMoney;
		}
		public void setRealTotalMoney(String realTotalMoney) {
			this.realTotalMoney = realTotalMoney;
		}
		public String getXunleiMoney() {
			return xunleiMoney;
		}
		public void setXunleiMoney(String xunleiMoney) {
			this.xunleiMoney = xunleiMoney;
		}
		public String getParterMoney() {
			return parterMoney;
		}
		public void setParterMoney(String parterMoney) {
			this.parterMoney = parterMoney;
		}
		public String getDevelopMoney() {
			return developMoney;
		}
		public void setDevelopMoney(String developMoney) {
			this.developMoney = developMoney;
		}
		public String getRealMoney() {
			return realMoney;
		}
		public void setRealMoney(String realMoney) {
			this.realMoney = realMoney;
		}
		
      
}
